==> apache-any23-2.4-src.zip: apache-any23-2.4-src/core/src/main/java/org/apache/any23/validator/DefaultValidationReport.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.any23.validator;

import java.util.List;

/**
 * Default implementation of {@link ValidationReport}.
 * 
 * @author Michele Mostarda (mostarda@fbk.eu)
 */
@XMLValidationReportSerializer.NodeName("validationReport")
public class DefaultValidationReport implements ValidationReport {

    private final List<Issue> issues;
    private final List<RuleActivation> ruleActivations;
    private final List<Error> errors;

    public DefaultValidationReport(
            List<Issue> issues,
            List<RuleActivation> ruleActivations,
            List<Error> errors
    ) {
        this.issues = issues;
        this.ruleActivations = ruleActivations;
        this.errors = errors;
    }

    public List<Issue> getIssues() {
        return issues;
    }

    public List<RuleActivation> getRuleActivations() {
        return ruleActivations;
    }

    public List<Error> getErrors() {
        return errors;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder();
        for(Issue issue : issues) {
            sb.append(issue).append('\n');
        }
        for(RuleActivation ruleActivation : ruleActivations) {
            sb.append(ruleActivation).append('\n');
        }
        for(Error error : errors) {
            sb.append(error).append('\n');
        }
        return sb.toString();
    }
}

==> apache-any23-2.6-src.zip: apache-any23-2.6-src/core/src/main/java/org/apache/any23/validator/DefaultValidationReport.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.any23.validator;

import java.util.List;

/**
 * Default implementation of {@link ValidationReport}.
 * 
 * @author Michele Mostarda (mostarda@fbk.eu)
 */
@XMLValidationReportSerializer.NodeName("validationReport")
public class DefaultValidationReport implements ValidationReport {

    private final List<Issue> issues;
    private final List<RuleActivation> ruleActivations;
    private final List<Error> errors;

    public DefaultValidationReport(List<Issue> issues, List<RuleActivation> ruleActivations, List<Error> errors) {
        this.issues = issues;
        this.ruleActivations = ruleActivations;
        this.errors = errors;
    }

    public List<Issue> getIssues() {
        return issues;
    }

    public List<RuleActivation> getRuleActivations() {
        return ruleActivations;
    }

    public List<Error> getErrors() {
        return errors;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder();
        for (Issue issue : issues) {
            sb.append(issue).append('\n');
        }
        for (RuleActivation ruleActivation : ruleActivations) {
            sb.append(ruleActivation).append('\n');
        }
        for (Error error : errors) {
            sb.append(error).append('\n');
        }
        return sb.toString();
    }
}
